Documentation
¶
Index ¶
- func NewBrokerTemplateInstanceInformer(client internalclientset.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredBrokerTemplateInstanceInformer(client internalclientset.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredTemplateInformer(client internalclientset.Interface, namespace string, ...) cache.SharedIndexInformer
- func NewFilteredTemplateInstanceInformer(client internalclientset.Interface, namespace string, ...) cache.SharedIndexInformer
- func NewTemplateInformer(client internalclientset.Interface, namespace string, ...) cache.SharedIndexInformer
- func NewTemplateInstanceInformer(client internalclientset.Interface, namespace string, ...) cache.SharedIndexInformer
- type BrokerTemplateInstanceInformer
- type Interface
- type TemplateInformer
- type TemplateInstanceInformer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewBrokerTemplateInstanceInformer ¶
func NewBrokerTemplateInstanceInformer(client internalclientset.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewBrokerTemplateInstanceInformer constructs a new informer for BrokerTemplateInstance type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredBrokerTemplateInstanceInformer ¶
func NewFilteredBrokerTemplateInstanceInformer(client internalclientset.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredBrokerTemplateInstanceInformer constructs a new informer for BrokerTemplateInstance type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredTemplateInformer ¶
func NewFilteredTemplateInformer(client internalclientset.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredTemplateInformer constructs a new informer for Template type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredTemplateInstanceInformer ¶
func NewFilteredTemplateInstanceInformer(client internalclientset.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredTemplateInstanceInformer constructs a new informer for TemplateInstance type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewTemplateInformer ¶
func NewTemplateInformer(client internalclientset.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewTemplateInformer constructs a new informer for Template type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewTemplateInstanceInformer ¶
func NewTemplateInstanceInformer(client internalclientset.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewTemplateInstanceInformer constructs a new informer for TemplateInstance type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type BrokerTemplateInstanceInformer ¶
type BrokerTemplateInstanceInformer interface {
Informer() cache.SharedIndexInformer
Lister() internalversion.BrokerTemplateInstanceLister
}
BrokerTemplateInstanceInformer provides access to a shared informer and lister for BrokerTemplateInstances.
type Interface ¶
type Interface interface {
// BrokerTemplateInstances returns a BrokerTemplateInstanceInformer.
BrokerTemplateInstances() BrokerTemplateInstanceInformer
// Templates returns a TemplateInformer.
Templates() TemplateInformer
// TemplateInstances returns a TemplateInstanceInformer.
TemplateInstances() TemplateInstanceInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.
type TemplateInformer ¶
type TemplateInformer interface {
Informer() cache.SharedIndexInformer
Lister() internalversion.TemplateLister
}
TemplateInformer provides access to a shared informer and lister for Templates.
type TemplateInstanceInformer ¶
type TemplateInstanceInformer interface {
Informer() cache.SharedIndexInformer
Lister() internalversion.TemplateInstanceLister
}
TemplateInstanceInformer provides access to a shared informer and lister for TemplateInstances.